@@ -14,7 +14,15 @@
 #include "tag.h"
 #include "utils.h"
 
-static void try_complete(const char* needle, std::string to_check, Output output);
+using std::endl;
+using std::function;
+using std::shared_ptr;
+using std::string;
+using std::to_string;
+using std::unique_ptr;
+using std::vector;
+
+static void try_complete(const char* needle, string to_check, Output output);
 static void try_complete(const char* needle, const char* to_check, Output output);
 
 static void complete_against_tags(int argc, char** argv, int pos, Output output);
@@ -23,21 +31,6 @@ static void complete_against_winids(int argc, char** argv, int pos, Output outpu
 static void complete_merge_tag(int argc, char** argv, int pos, Output output);
 static int complete_against_commands(int argc, char** argv, int position, Output output);
 
-// Quarantined inclusion to avoid polluting the global namespace:
-namespace search_h {
-    #include <search.h>
-} // namespace search_h
-using search_h::lfind;
-
-using std::endl;
-using std::function;
-using std::pair;
-using std::shared_ptr;
-using std::string;
-using std::to_string;
-using std::unique_ptr;
-using std::vector;
-
 // if the current completion needs shell quoting and other shell specific
 // behaviour
 static bool g_shell_quoting = false;
@@ -46,10 +39,7 @@ static const char* completion_directions[]    = { "left", "right", "down", "up",
 static const char* completion_focus_args[]    = { "-i", "-e", nullptr };
 static const char* completion_special_winids[]= { "urgent", "", nullptr };
 static const char* completion_use_index_args[]= { "--skip-visible", nullptr };
-static const char* completion_cycle_all_args[]= { "--skip-invisible", nullptr };
 static const char* completion_pm_one[]= { "+1", "-1", nullptr };
-static const char* completion_detect_monitors_args[] =
-    { "-l", "--list", "--list-all", "--no-disjoin", /* TODO: "--keep-small", */ nullptr };
 static const char* completion_split_modes[]= { "horizontal", "vertical", "left", "right", "top", "bottom", "explode", "auto", nullptr };
 static const char* completion_split_ratios[]= {
     "0.1", "0.2", "0.3", "0.4", "0.5", "0.6", "0.7", "0.8", "0.9", nullptr };
@@ -85,13 +75,11 @@ struct {
     { "focus_nth",      2,  no_completion },
     { "close",          2,  no_completion },
     { "cycle",          2,  no_completion },
-    { "cycle_all",      3,  no_completion },
     { "set_layout",     2,  no_completion },
     { "split",          3,  no_completion },
     { "raise",          2,  no_completion },
     { "jumpto",         2,  no_completion },
     { "bring",          2,  no_completion },
-    { "resize",         3,  no_completion },
     { "focus_edge",     2,  no_completion },
     { "shift_edge",     2,  no_completion },
     { "shift",          3,  no_completion },
@@ -145,12 +133,8 @@ struct {
     { "bring",          EQ, 1,  complete_against_winids, 0 },
     { "close",          EQ, 1,  complete_against_winids, 0 },
     { "cycle",          EQ, 1,  nullptr, completion_pm_one },
-    { "cycle_all",      EQ, 1,  nullptr, completion_cycle_all_args },
-    { "cycle_all",      EQ, 1,  nullptr, completion_pm_one },
-    { "cycle_all",      EQ, 2,  nullptr, completion_pm_one },
     { "cycle_monitor",  EQ, 1,  nullptr, completion_pm_one },
     { "dump",           EQ, 1,  complete_against_tags, 0 },
-    { "detect_monitors", GE, 1,  nullptr, completion_detect_monitors_args },
     { "layout",         EQ, 1,  complete_against_tags, 0 },
     { "load",           EQ, 1,  complete_against_tags, 0 },
     { "merge_tag",      EQ, 1,  complete_against_tags, 0 },
@@ -162,7 +146,6 @@ struct {
     { "raise",          EQ, 1,  complete_against_winids, 0 },
     { "jumpto",         EQ, 1,  nullptr, completion_special_winids },
     { "jumpto",         EQ, 1,  complete_against_winids, 0 },
-    { "resize",         EQ, 1,  nullptr, completion_directions },
     { "shift_edge",     EQ, 1,  nullptr, completion_directions },
     { "shift",          EQ, 1,  nullptr, completion_directions },
     { "shift",          EQ, 1,  nullptr, completion_focus_args },
@@ -283,6 +266,14 @@ int Commands::call(Input args, Output out) {
     return command_table->callCommand(args, out);
 }
 
+bool Commands::commandExists(const string& commandName)
+{
+    if (!command_table) {
+        return false;
+    }
+    return command_table->find(commandName) != command_table->end();
+}
+
 shared_ptr<const CommandTable> Commands::get() {
     if (!command_table) {
         throw std::logic_error("CommandTable not initialized, but get() called.");
@@ -316,8 +307,9 @@ void Commands::complete(Completion& completion) {
 // Old C-ish interface to commands:
 
 int call_command(int argc, char** argv, Output output) {
-    if (argc < 1)
+    if (argc < 1) {
         return HERBST_COMMAND_NOT_FOUND;
+    }
 
     string cmd(argv[0]);
     vector<string> args;
@@ -472,7 +464,7 @@ static bool parameter_expected(int argc, char** argv, int pos) {
         /* no parameter if there is no command */
         return false;
     }
-    for (int i = 0; i < LENGTH(g_parameter_expected)
+    for (size_t i = 0; i < LENGTH(g_parameter_expected)
                     && g_parameter_expected[i].command; i++) {
         if (pos < g_parameter_expected[i].min_index) {
             continue;
@@ -539,7 +531,7 @@ int complete_against_commands(int argc, char** argv, int position,
     if (argc >= 1) {
         const char* cmd_str = (argc >= 1) ? argv[0] : "";
         // complete parameters for commands
-        for (int i = 0; i < LENGTH(g_completions); i++) {
+        for (size_t i = 0; i < LENGTH(g_completions); i++) {
             bool matches = false;
             switch (g_completions[i].relation) {
                 case LE: matches = position <= g_completions[i].index; break;
@@ -548,7 +540,7 @@ int complete_against_commands(int argc, char** argv, int position,
             }
             if (!matches
                 || !g_completions[i].command
-                || strcmp(cmd_str, g_completions[i].command)) {
+                || strcmp(cmd_str, g_completions[i].command) != 0) {
                 continue;
             }
             const char* needle = (position < argc) ? argv[position] : "";
